Index: /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFChoice.java
===================================================================
--- /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFChoice.java	(revision 382)
+++ /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFChoice.java	(revision 383)
@@ -45,27 +45,29 @@
      * @return An array of {@link ConstraintSyntaxTree}s.
      */
-    ConstraintSyntaxTree[] getBooleanConstraintSyntaxTree(AbstractReader reader) {
-        // Create choiceItems.size() Constraints with all choiceItems OR'd together and 1 negated each.
-        // Also contains NOT choiceName since the choice only applies if choiceName is true
+    List<ConstraintSyntaxTree> getBooleanConstraintSyntaxTree(AbstractReader reader) {
+        //ConstraintSyntaxTree[] trees = new ConstraintSyntaxTree[choiceItems.size()];
+        List<ConstraintSyntaxTree> trees = new ArrayList<ConstraintSyntaxTree>();
+        Variable choiceVar = varPool.obtainVariable(reader.getVariable(choiceName));
+        OCLFeatureCall notChoiceVar = new OCLFeatureCall(choiceVar, OclKeyWords.NOT);
         
-        ConstraintSyntaxTree[] trees = new ConstraintSyntaxTree[choiceItems.size()];
-        Variable choiceVar = varPool.obtainVariable(reader.getVariable(choiceName));
+        // Create one tree with all variables OR'd together
+        ConstraintSyntaxTree allItemsTree = notChoiceVar;
         
-        for (int i = 0; i < trees.length; i++) {
-            
-            trees[i] = new OCLFeatureCall(choiceVar, OclKeyWords.NOT);
-            
-            for (int j = 0; j < choiceItems.size(); j++) {
-                Variable var = varPool.obtainVariable(reader.getVariable(choiceItems.get(j)));
-                // variable #i should be negated
-                if (j == i) {
-                    trees[i] = new OCLFeatureCall(trees[i], OclKeyWords.OR,
-                            new OCLFeatureCall(var, OclKeyWords.NOT));
-                } else {
-                    trees[i] = new OCLFeatureCall(trees[i], OclKeyWords.OR, var);
-                }
+        // And for each unique combination of choiceItems:
+        for (int i = 0; i < choiceItems.size(); i++) {
+            Variable var1 = varPool.obtainVariable(reader.getVariable(choiceItems.get(i)));
+            OCLFeatureCall notVar1 = new OCLFeatureCall(var1, OclKeyWords.NOT);
+            for (int j = i + 1; j < choiceItems.size(); j++) {
+                // Add the 2 variables negated and OR'd together:
+                Variable var2 = varPool.obtainVariable(reader.getVariable(choiceItems.get(j)));
+                OCLFeatureCall notVar2 = new OCLFeatureCall(var2, OclKeyWords.NOT);
+                OCLFeatureCall call = new OCLFeatureCall(notVar1, OclKeyWords.OR, notVar2);
+                trees.add(new OCLFeatureCall(notChoiceVar, OclKeyWords.OR, call));
             }
             
+            allItemsTree = new OCLFeatureCall(allItemsTree, OclKeyWords.OR, var1);
         }
+        
+        trees.add(allItemsTree);
         
         return trees;
Index: /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFDefaultCondition.java
===================================================================
--- /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFDefaultCondition.java	(revision 383)
+++ /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFDefaultCondition.java	(revision 383)
@@ -0,0 +1,147 @@
+package de.uni_hildesheim.sse.trans.in.rsf;
+
+import java.util.ArrayList;
+import java.util.List;
+
+import de.uni_hildesheim.sse.model.cst.ConstraintSyntaxTree;
+import de.uni_hildesheim.sse.model.cst.OCLFeatureCall;
+import de.uni_hildesheim.sse.model.cst.Variable;
+import de.uni_hildesheim.sse.model.varModel.datatypes.Enum;
+import de.uni_hildesheim.sse.model.varModel.datatypes.OclKeyWords;
+import de.uni_hildesheim.sse.trans.in.AbstractReader;
+import de.uni_hildesheim.sse.trans.in.ParserException;
+
+/**
+ * Represents a condition implied by the default value of a variable. Should not be added to the model if
+ * the user can modify the variable (i.e. HasPrompt).<br />
+ * If the variable is a boolean the pure boolean constraint will look like this:<br />
+ * <code>
+ * NOT condition OR variable
+ * </code><br />
+ * (varible will be negated if the default value is "n" instead of "y".<br />
+ * If the variable is not a boolean the pure boolean constraint will lokk like:<br />
+ * <code>
+ * NOT condition OR variable=defaultValue
+ * </code><br />
+ * If the item has a prompt condition the above expression is combined with OR NOT promptCondition
+ * 
+ * @author Adam Krafczyk
+ */
+class RSFDefaultCondition extends RSFCondition {
+//    private static final EASyLogger LOGGER = EASyLoggerFactory.INSTANCE.getLogger(RSFDefaultCondition.class,
+//            "RSFDefaultCondition");
+
+    private RSFItem variable;
+    private String defaultValue;
+    private String condition;
+    
+    /**
+     * Creates a {@link RSFDefaultCondition} for a Default line read from a .rsf file.
+     * If the variable is boolean only "y" and "n" are allowed as default values.
+     * @param variable The variable with the (possible) default value.
+     * @param defaultValue The default value of the variable.
+     * @param condition The condition that has to be true if the default value has to be set.
+     */
+    RSFDefaultCondition(RSFItem variable, String defaultValue, String condition) {
+        this.variable = variable;
+        this.defaultValue = defaultValue;
+        this.condition = condition;
+    }
+    
+    @Override
+    List<ConstraintSyntaxTree> toPureBooleanConstraintSyntaxTree(RSFReader reader) throws ParserException {
+        List<ConstraintSyntaxTree> defaultVariableConditions = new ArrayList<ConstraintSyntaxTree>();
+        
+        if (variable.getDatatype().equals(Datatype.BOOLEAN)) {
+            /*
+             * Add (NOT variable OR defaultVariable) AND (varaible or NOT defaultVariable) to the list of conditions
+             */
+            ConstraintSyntaxTree defaultVariable = null;
+            if (defaultValue.equals("y") || defaultValue.equals("'y'")) {
+                defaultVariable = varPool.obtainVariable(reader.getVariable(variable.getName()));
+                
+            } else if (defaultValue.equals("n") || defaultValue.equals("'n'")) {
+                defaultVariable = varPool.obtainVariable(reader.getVariable(variable.getName()));
+                defaultVariable = new OCLFeatureCall(defaultVariable, OclKeyWords.NOT);
+                
+            } else {
+                defaultVariable = getPureBooleanConstraintSyntaxTree(reader, defaultValue,
+                        variable.getName());
+                if (defaultVariable == null) {
+                    defaultVariable = varPool.obtainVariable(reader.getVariable(variable.getName()));
+                }
+            }
+            
+            Variable variable = varPool.obtainVariable(reader.getVariable(this.variable.getName()));
+            OCLFeatureCall notVariable = new OCLFeatureCall(variable, OclKeyWords.NOT);
+            OCLFeatureCall notDefaultVariable = new OCLFeatureCall(defaultVariable, OclKeyWords.NOT);
+            
+            defaultVariableConditions.add(new OCLFeatureCall(variable, OclKeyWords.OR, notDefaultVariable));
+            defaultVariableConditions.add(new OCLFeatureCall(notVariable, OclKeyWords.OR, defaultVariable));
+            
+        } else {
+            /*
+             * If not boolean that add add string (or integer) comparison directly
+             */
+            defaultValue = defaultValue.replace("'", "");
+            ConstraintSyntaxTree defaultTree = varPool.obtainVariable(reader.getVariable(variable.getName() + "="
+                        + defaultValue));
+            defaultVariableConditions.add(defaultTree);
+        }
+        
+        String promptConditionString = variable.getPromptCondition();
+        ConstraintSyntaxTree promptCondition = null;
+        boolean hasPrompt = false;
+        if (promptConditionString != null) {
+            if (promptConditionString.equals("y") || promptConditionString.equals("'y'")) {
+                hasPrompt = true;
+            } else if (!promptConditionString.equals("n") && !promptConditionString.equals("'n'")) {
+                promptCondition = getPureBooleanConstraintSyntaxTree(reader,
+                        promptConditionString, variable.getName());
+            }
+        }
+        
+        List<ConstraintSyntaxTree> result = new ArrayList<ConstraintSyntaxTree>();
+        
+        /*
+         * prompt OR NOT condition OR defaultVariableConditions
+         */
+        if (!hasPrompt) {
+            
+            ConstraintSyntaxTree condition = getPureBooleanConstraintSyntaxTree(reader, this.condition,
+                    variable.getName());
+            
+            ConstraintSyntaxTree prependCall = null;
+            
+            if (promptCondition != null) {
+                prependCall = promptCondition;
+            }
+            if (condition != null) {
+                if (prependCall == null) {
+                    prependCall = new OCLFeatureCall(condition, OclKeyWords.NOT);
+                } else {
+                    OCLFeatureCall notCondition = new OCLFeatureCall(condition, OclKeyWords.NOT);
+                    prependCall = new OCLFeatureCall(prependCall, OclKeyWords.OR, notCondition);
+                }
+            }
+            
+            for (ConstraintSyntaxTree defaultVariableCondition : defaultVariableConditions) {
+                if (prependCall != null) {
+                    defaultVariableCondition = new OCLFeatureCall(prependCall, OclKeyWords.OR,
+                            defaultVariableCondition);
+                }
+                result.add(defaultVariableCondition);
+            }
+            
+        }
+        
+        return result;
+    }
+
+    @Override
+    ConstraintSyntaxTree toNotBooleanConstraintSyntaxTree(AbstractReader reader, Enum tristate) throws ParserException {
+        // TODO Implement
+        return null;
+    }
+
+}
Index: /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFDependsCondition.java
===================================================================
--- /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFDependsCondition.java	(revision 382)
+++ /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFDependsCondition.java	(revision 383)
@@ -30,5 +30,5 @@
  * </code> <br />
  * If condition contains a tristate variable and <i>variable</i> is a tristate variable, the following condition will
- * be added with AND: <br />
+ * be added: <br />
  * <code>
  * NOT <i>variable_MODULE</i> OR <i>condition_variable_MODULE</i>
@@ -60,5 +60,5 @@
     
     @Override
-    ConstraintSyntaxTree toPureBooleanConstraintSyntaxTree(RSFReader reader) throws ParserException {
+    List<ConstraintSyntaxTree> toPureBooleanConstraintSyntaxTree(RSFReader reader) throws ParserException {
         DecisionVariableDeclaration varDecl = reader.getVariable(variable);
         OCLFeatureCall notVar = new OCLFeatureCall(varPool.obtainVariable(varDecl), OclKeyWords.NOT);
@@ -66,8 +66,8 @@
         ConstraintSyntaxTree condition = getPureBooleanConstraintSyntaxTree(reader, this.condition, variable);
         
-        ConstraintSyntaxTree result = null;
+        List<ConstraintSyntaxTree> result  = new ArrayList<ConstraintSyntaxTree>();
         
         if (condition != null) {
-            result = new OCLFeatureCall(notVar, OclKeyWords.OR, condition);
+            result.add(new OCLFeatureCall(notVar, OclKeyWords.OR, condition));
             
             List<RSFItem> tristates = new ArrayList<RSFItem>();
@@ -94,6 +94,5 @@
                     Variable conditionModuleVar = varPool.obtainVariable(conditionModuleVarDecl);
                     
-                    result = new OCLFeatureCall(result, OclKeyWords.AND,
-                            new OCLFeatureCall(notModuleVar, OclKeyWords.OR, conditionModuleVar));
+                    result.add(new OCLFeatureCall(notModuleVar, OclKeyWords.OR, conditionModuleVar));
                 } else {
                     // TODO: what to do?
Index: /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFItem.java
===================================================================
--- /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFItem.java	(revision 382)
+++ /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFItem.java	(revision 383)
@@ -9,4 +9,7 @@
     private String name;
     private Datatype type;
+    private boolean hasPrompt;
+    private String promptCondition;
+    private RSFDefaultCondition defaultCondition;
     
     /**
@@ -42,3 +45,52 @@
         return type;
     }
+    
+    /**
+     * Getter for the HasPrompt attribute of the variable.
+     * @return Whether the variable is changeable by the user.
+     */
+    public boolean hasPrompt() {
+        return hasPrompt;
+    }
+    
+    /**
+     * Setter for the HasPrompt attribute of the variable.
+     * @param hasPrompt Whether the variable is changeable by the user.
+     */
+    public void setHasPrompt(boolean hasPrompt) {
+        this.hasPrompt = hasPrompt;
+    }
+    
+    /**
+     * Getter for the default condition of this variable.
+     * @return The default condition of this variable.
+     */
+    public RSFDefaultCondition getDefaultCondition() {
+        return defaultCondition;
+    }
+    
+    /**
+     * Setter for the default condition of this variable.
+     * @param defaultCondition The default condition for this variable.
+     */
+    public void setDefaultCondition(RSFDefaultCondition defaultCondition) {
+        this.defaultCondition = defaultCondition;
+    }
+    
+    /**
+     * Getter for the condition that toggles the prompt for the variable.
+     * @return The condition; <code>null</code> if not found in the .rsf file.
+     */
+    public String getPromptCondition() {
+        return promptCondition;
+    }
+    
+    /**
+     * Getter for the condition that toggles the prompt for the variable.
+     * @param promptCondition The condition.
+     */
+    public void setPromptCondition(String promptCondition) {
+        this.promptCondition = promptCondition;
+    }
+    
 }
Index: /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFItemSelectsCondition.java
===================================================================
--- /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFItemSelectsCondition.java	(revision 382)
+++ /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFItemSelectsCondition.java	(revision 383)
@@ -1,3 +1,6 @@
 package de.uni_hildesheim.sse.trans.in.rsf;
+
+import java.util.ArrayList;
+import java.util.List;
 
 import de.uni_hildesheim.sse.model.cst.ConstraintSyntaxTree;
@@ -55,5 +58,5 @@
     
     @Override
-    ConstraintSyntaxTree toPureBooleanConstraintSyntaxTree(RSFReader reader) throws ParserException {
+    List<ConstraintSyntaxTree> toPureBooleanConstraintSyntaxTree(RSFReader reader) throws ParserException {
         DecisionVariableDeclaration varDecl = reader.getVariable(variable);
         Variable var = varPool.obtainVariable(varDecl);
@@ -75,5 +78,7 @@
         }
         
-        return result;
+        List<ConstraintSyntaxTree> list  = new ArrayList<ConstraintSyntaxTree>();
+        list.add(result);
+        return list;
     }
     
Index: /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFModuleCondition.java
===================================================================
--- /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFModuleCondition.java	(revision 382)
+++ /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFModuleCondition.java	(revision 383)
@@ -1,3 +1,6 @@
 package de.uni_hildesheim.sse.trans.in.rsf;
+
+import java.util.ArrayList;
+import java.util.List;
 
 import de.uni_hildesheim.sse.model.cst.ConstraintSyntaxTree;
@@ -30,9 +33,11 @@
     
     @Override
-    ConstraintSyntaxTree toPureBooleanConstraintSyntaxTree(RSFReader reader) throws ParserException {
+    List<ConstraintSyntaxTree> toPureBooleanConstraintSyntaxTree(RSFReader reader) throws ParserException {
         Variable var = varPool.obtainVariable(reader.getVariable(variable));
         Variable moduleVar = varPool.obtainVariable(reader.getVariable(moduleVariable));
         
-        return new OCLFeatureCall(var, OclKeyWords.OR, new OCLFeatureCall(moduleVar, OclKeyWords.NOT));
+        List<ConstraintSyntaxTree> list  = new ArrayList<ConstraintSyntaxTree>();
+        list.add(new OCLFeatureCall(var, OclKeyWords.OR, new OCLFeatureCall(moduleVar, OclKeyWords.NOT)));
+        return list;
     }
     
Index: /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFReader.java
===================================================================
--- /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFReader.java	(revision 382)
+++ /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFReader.java	(revision 383)
@@ -135,17 +135,28 @@
                 throw new ParserException(ParserExceptionType.NOT_SUPPORTED_DATATYPE);
             }
+            
+            // Add default condition if no prompt
+            if (!item.hasPrompt() || item.getPromptCondition() != null) {
+                RSFDefaultCondition defaultCondition = item.getDefaultCondition();
+                if (defaultCondition != null) {
+                    conditions.add(defaultCondition);
+                } else {
+                    // TODO
+                    LOGGER.debug("No prompt and no default for varible: " + item.getName());
+                }
+            }
         }
         
         // 2. Add conditions
         for (RSFCondition condition : conditions) {
-            try {
+            List<ConstraintSyntaxTree> trees = condition.toPureBooleanConstraintSyntaxTree(this);
+            for (ConstraintSyntaxTree tree : trees) {
                 Constraint constraint = new Constraint(model);
-                ConstraintSyntaxTree tree = condition.toPureBooleanConstraintSyntaxTree(this);
-                if (tree != null) {
+                try {
                     constraint.setConsSyntax(tree);
                     model.add(constraint);
-                }
-            } catch (CSTSemanticException e) {
-                LOGGER.exception(e);
+                } catch (CSTSemanticException e) {
+                    LOGGER.exception(e);
+                }
             }
         }
@@ -153,5 +164,5 @@
         // 3. Add choice conditions
         for (RSFChoice choice : choices.values()) {
-            ConstraintSyntaxTree[] trees = choice.getBooleanConstraintSyntaxTree(this);
+            List<ConstraintSyntaxTree> trees = choice.getBooleanConstraintSyntaxTree(this);
             for (ConstraintSyntaxTree tree : trees) {
                 Constraint constraint = new Constraint(model);
@@ -241,12 +252,14 @@
                     break;
                 case "Prompt":
-                    // Default value in [2]
+                    // Condition in [2]
+                    item.setPromptCondition(columns[2]);
                     break;
                 case "Default":
                     // Default value in [2], condition in [3]
-                    // TODO: read condition? I guess not...
+                    item.setDefaultCondition(new RSFDefaultCondition(item, columns[2], columns[3]));
                     break;
                 case "HasPrompts":
-                    // TODO: what is this?
+                    // 0 or 1 in [2]
+                    item.setHasPrompt(columns[2].equals("1"));
                     break;
                 case "ItemSelects":
Index: /Code/ModelTranslator/test/de/uni_hildesheim/sse/trans/in/rsf/RSFReaderTest.java
===================================================================
--- /Code/ModelTranslator/test/de/uni_hildesheim/sse/trans/in/rsf/RSFReaderTest.java	(revision 382)
+++ /Code/ModelTranslator/test/de/uni_hildesheim/sse/trans/in/rsf/RSFReaderTest.java	(revision 383)
@@ -38,6 +38,6 @@
         
         ConstraintFinder cFinder = new ConstraintFinder(project);
-        // 8 conditions + 2 _MODULE conditions
-        Assert.assertEquals(10, cFinder.getConstraints().size());
+        // 8 conditions + 2 _MODULE conditions + 1 Tristate-Depends-on-Tristate condition
+        Assert.assertEquals(11, cFinder.getConstraints().size());
         
 //        for (Constraint c : cFinder.getConstraints()) {
Index: /Code/ModelTranslator/test/de/uni_hildesheim/sse/trans/scenario/RsfToDimacsTranslationTest.java
===================================================================
--- /Code/ModelTranslator/test/de/uni_hildesheim/sse/trans/scenario/RsfToDimacsTranslationTest.java	(revision 382)
+++ /Code/ModelTranslator/test/de/uni_hildesheim/sse/trans/scenario/RsfToDimacsTranslationTest.java	(revision 383)
@@ -78,6 +78,6 @@
      * </ul>
      */
-    @Ignore("Currently, not supported")
     @Test
+    @Ignore("TODO")
     public void testDefaultsAndPrompts() {
         File input = new File(AllTests.INPUT_FOLDER, "testModel_DefaultAndPrompts.rsf");
@@ -90,6 +90,6 @@
         String result = DimacsTestUtils.loadModel(input, noOptimization, true);
         System.out.println(result);
-        int arch32 = DimacsTestUtils.getNumberOfVariable(result, "ARCH='x86'");
-        int arch64 = DimacsTestUtils.getNumberOfVariable(result, "ARCH='x86_64'");
+        int arch32 = DimacsTestUtils.getNumberOfVariable(result, "ARCH=x86");
+        int arch64 = DimacsTestUtils.getNumberOfVariable(result, "ARCH=x86_64");
         int bit = DimacsTestUtils.getNumberOfVariable(result, "64BIT");
         
@@ -133,17 +133,18 @@
         /*
          * Test whether the following constraints are included:
-         * NOT(CHOICE_12) OR NOT(HZ_100) OR HZ_250 OR HZ_300 OR HZ_1000
-         * NOT(CHOICE_12) OR HZ_100 OR NOT(HZ_250) OR HZ_300 OR HZ_1000
-         * NOT(CHOICE_12) OR HZ_100 OR HZ_250 OR NOT(HZ_300) OR HZ_1000
-         * NOT(CHOICE_12) OR HZ_100 OR HZ_250 OR HZ_300 OR NOT(HZ_1000)
+         * NOT(CHOICE_12) OR NOT(HZ_100) OR NOT(HZ_250)
+         * NOT(CHOICE_12) OR NOT(HZ_100) OR NOT(HZ_300)
+         * NOT(CHOICE_12) OR NOT(HZ_100) OR NOT(HZ_1000)
+         * (skip other combinations)
+         * NOT(CHOICE_12) OR HZ_100 OR HZ_250 OR HZ_300 OR HZ_1000
          */
         Assert.assertTrue("Error: Missing choice constraint",
-                DimacsTestUtils.containsConstraint(result, -1 * choice12, -1 * hz100, hz250, hz300, hz1000));
+                DimacsTestUtils.containsConstraint(result, -1 * choice12, -1 * hz100, -1 * hz250));
         Assert.assertTrue("Error: Missing choice constraint",
-                DimacsTestUtils.containsConstraint(result, -1 * choice12, hz100, -1 * hz250, hz300, hz1000));
+                DimacsTestUtils.containsConstraint(result, -1 * choice12, -1 * hz100, -1 * hz300));
         Assert.assertTrue("Error: Missing choice constraint",
-                DimacsTestUtils.containsConstraint(result, -1 * choice12, hz100, hz250, -1 * hz300, hz1000));
+                DimacsTestUtils.containsConstraint(result, -1 * choice12, -1 * hz100, -1 * hz1000));
         Assert.assertTrue("Error: Missing choice constraint",
-                DimacsTestUtils.containsConstraint(result, -1 * choice12, hz100, hz250, hz300, -1 * hz1000));
+                DimacsTestUtils.containsConstraint(result, -1 * choice12, hz100, hz250, hz300, hz1000));
     }
 

Index: /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFCondition.java
===================================================================
--- /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFCondition.java	(revision 382)
+++ /Code/ModelTranslator/src/de/uni_hildesheim/sse/trans/in/rsf/RSFCondition.java	(revision 383)
@@ -1,3 +1,5 @@
 package de.uni_hildesheim.sse.trans.in.rsf;
+
+import java.util.List;
 
 import de.uni_hildesheim.sse.model.cst.ConstraintSyntaxTree;
@@ -20,11 +22,11 @@
     
     /**
-     * Returns this condition as a {@link ConstraintSyntaxTree} in pure boolean format.
+     * Returns this condition as a pure boolean expression.
      * @param reader The reader to get the variables from.
      * @return A {@link ConstraintSyntaxTree} representing this condition. <code>null</code> if condition is optimized
      *         out.
      * @throws ParserException If the conditions contains an operation, that is not supported by the parser.
      */
-    abstract ConstraintSyntaxTree toPureBooleanConstraintSyntaxTree(RSFReader reader) throws ParserException;
+    abstract List<ConstraintSyntaxTree> toPureBooleanConstraintSyntaxTree(RSFReader reader) throws ParserException;
     
     /**
@@ -20,11 +22,11 @@
      * @param reader The reader to get the variables from.
-     * @return A {@link ConstraintSyntaxTree} representing this condition. <code>null</code> if condition is optimized
-     *         out.
+     * @return A List of {@link ConstraintSyntaxTree}s representing this expression. The parts should be handled as if
+     *         combined with AND. empty if expression is optimized out.
      * @throws ParserException If the conditions contains an operation, that is not supported by the parser.
      */